@@ -60,7 +60,10 @@ html_search_new (HTMLEngine *e, const gchar *text, gboolean case_sensitive, gboo
 		HTMLObject *o;
  
 		ns->stack = NULL;
-		ns->start_pos = e->cursor->offset - 1;
+		if (ns->start_pos > 0 )
+			ns->start_pos = e->cursor->offset - 1;
+		else
+			ns->start_pos = 0;
 		for (o = e->cursor->object; o; o = o->parent)
 			html_search_push (ns, o);
 		ns->stack = g_slist_reverse (ns->stack);
